@@ -6,7 +6,7 @@
  * Descr.: foreign interface support                                       *
  * Author: Daniel Diaz                                                     *
  *                                                                         *
- * Copyright (C) 1999-2012 Daniel Diaz                                     *
+ * Copyright (C) 1999-2013 Daniel Diaz                                     *
  *                                                                         *
  * This file is part of GNU Prolog                                         *
  *                                                                         *
@@ -35,7 +35,6 @@
  * not, see http://www.gnu.org/licenses/.                                  *
  *-------------------------------------------------------------------------*/
 
-/* $Id$ */
 
 #include <string.h>
 
@@ -234,7 +233,7 @@ void
 Pl_Emit_Syntax_Error(char *file_name, int err_line, int err_col, char *err_msg)
 {
   Pl_Set_Last_Syntax_Error(file_name, err_line, err_col, err_msg);
-  Pl_Syntax_Error(Flag_Value(FLAG_SYNTAX_ERROR));
+  Pl_Syntax_Error(Flag_Value(syntax_error));
 }
 
 
