@@ -6,7 +6,7 @@
  * Descr.: general engine - header file                                    *
  * Author: Daniel Diaz                                                     *
  *                                                                         *
- * Copyright (C) 1999-2012 Daniel Diaz                                     *
+ * Copyright (C) 1999-2013 Daniel Diaz                                     *
  *                                                                         *
  * This file is part of GNU Prolog                                         *
  *                                                                         *
@@ -35,7 +35,6 @@
  * not, see http://www.gnu.org/licenses/.                                  *
  *-------------------------------------------------------------------------*/
 
-/* $Id$ */
 
 #ifdef NO_STACK_TEST
 #   undef  M_Check_Stacks()
@@ -78,10 +77,10 @@ int pl_devel_mode;
 
 char pl_glob_buff[10240];
 
-PlLong *pl_base_fl;			/* overwritten by foreign if present */
+PlLong *pl_base_fl;		/* overwritten by foreign if present */
 double *pl_base_fd;		/* overwritten by foreign if present */
 
-int pl_use_gui;
+int pl_le_mode;			/* LE_MODE_HOOK if GUI */
 
 #else
 
@@ -96,7 +95,7 @@ extern char pl_glob_buff[];
 extern PlLong *pl_base_fl;
 extern double *pl_base_fd;
 
-extern int pl_use_gui;
+extern int pl_le_mode;
 
 #endif
 
@@ -119,7 +118,7 @@ void Pl_Set_Heap_Actual_Start(WamWord *heap_actual_start);
 
 
 void Pl_Execute_Directive(int pl_file, int pl_line, Bool is_system,
-		       CodePtr proc);
+			  CodePtr proc);
 
 Bool Pl_Try_Execute_Top_Level(void);
 
