@@ -2,14 +2,14 @@
 #define __GNU_PROLOG__        	1
 #define __GPROLOG__           	1
 #define __GPROLOG_MINOR__     	4
-#define __GPROLOG_PATCHLEVEL__	3
-#define __GPROLOG_VERSION__   	10403
+#define __GPROLOG_PATCHLEVEL__	4
+#define __GPROLOG_VERSION__   	10404
 
 #define PROLOG_DIALECT  	"gprolog"
 #define PROLOG_NAME     	"GNU Prolog"
-#define PROLOG_VERSION  	"1.4.3"
-#define PROLOG_DATE     	"Mar 29 2013"
-#define PROLOG_COPYRIGHT	"Copyright (C) 1999-2012 Daniel Diaz"
+#define PROLOG_VERSION  	"1.4.4"
+#define PROLOG_DATE     	"Apr 22 2013"
+#define PROLOG_COPYRIGHT	"Copyright (C) 1999-2013 Daniel Diaz"
 
 #define PL_MIN_INTEGER		-268435456
 #define PL_MAX_INTEGER		268435455
