@@ -6,7 +6,7 @@
  * Descr.: code generation                                                 *
  * Author: Daniel Diaz                                                     *
  *                                                                         *
- * Copyright (C) 1999-2012 Daniel Diaz                                     *
+ * Copyright (C) 1999-2013 Daniel Diaz                                     *
  *                                                                         *
  * This file is part of GNU Prolog                                         *
  *                                                                         *
@@ -35,7 +35,6 @@
  * not, see http://www.gnu.org/licenses/.                                  *
  *-------------------------------------------------------------------------*/
 
-/* $Id$ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -46,6 +45,8 @@
 #include "../Wam2Ma/bt_string.c"
 #include "../TopComp/copying.c"
 
+#define MA2ASM_FILE
+
 #include "ma_parser.h"
 #include "ma_protos.h"
 
@@ -91,8 +92,6 @@ CodeInf;
  * Global Variables                *
  *---------------------------------*/
 
-int can_produce_pic_code;	/* can be overwritten by mappers */
-
 char *file_name_in;
 char *file_name_out;
 int pic_code;
