@@ -6,7 +6,7 @@
  * Descr.: translation file for Linux on AMD x86-64                        *
  * Author: Gwenole Beauchesne, Ozaki Kiichi and Daniel Diaz                *
  *                                                                         *
- * Copyright (C) 1999-2012 Daniel Diaz and Gwenole Beauchesne              *
+ * Copyright (C) 1999-2013 Daniel Diaz and Gwenole Beauchesne              *
  *                                                                         *
  * This file is part of GNU Prolog                                         *
  *                                                                         *
@@ -35,7 +35,6 @@
  * not, see http://www.gnu.org/licenses/.                                  *
  *-------------------------------------------------------------------------*/
 
-/* $Id$ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -107,9 +106,6 @@
  * Global Variables                *
  *---------------------------------*/
 
-int can_produce_pic_code = 1;	/* overwritte var of ma2asm.c */
-extern int pic_code;
-
 static double dbl_tbl[MAX_DOUBLES_IN_PRED];
 static int nb_dbl = 0;
 static int dbl_lc_no = 0;
@@ -147,6 +143,7 @@ static const char *fpr_arg[MAX_FPR_ARGS] = {
 #endif
           /* variables for ma_parser.c / ma2asm.c */
 
+int can_produce_pic_code = 1;
 char *comment_prefix = "#";
 #ifdef M_x86_64_darwin
 char *local_symb_prefix = "L";
